idlefw/inc/framework/caicpscommandbuffer.h
branchRCL_3
changeset 64 b276298d5729
parent 51 15e4dd19031c
child 74 edd621764147
--- a/idlefw/inc/framework/caicpscommandbuffer.h	Wed Apr 14 16:16:44 2010 +0300
+++ b/idlefw/inc/framework/caicpscommandbuffer.h	Tue Apr 27 16:57:49 2010 +0300
@@ -79,6 +79,13 @@
      */
     void Flush();
     
+    /**
+    * Gets the CPS interface 
+    *
+    * @since S60 5.2
+    */
+    void GetCPSInterfaceL();
+    
 private:
     // from MAiCpsCommandBuffer
 
@@ -86,16 +93,27 @@
      * @see MAiCpsCommandBuffer
      */    
     void AddCommand( const TDesC& aPluginId, const TDesC& aType, 
-            CLiwDefaultMap* aFilter, const TDesC8& aAction);
+        CLiwDefaultMap* aFilter, const TDesC8& aAction);
+
+    /**
+     * @see MAiCpsCommandBuffer
+     */        
+    CLiwServiceHandler* ServiceHandler() const;            
+    
+    /**
+     * @see MAiCpsCommandBuffer
+     */        
+    MLiwInterface* CpsInterface() const;
     
 private:
     // new functions
+    
     /**
     * Gets the CPS interface 
     *
     * @since S60 5.2
-    */
-    void GetCPSInterfaceL();
+    */    
+    void DetachL();
     
     /**
     * Adds a CPS command execute commnad for a spcific Plugin
@@ -86,16 +93,27 @@
     /**
-    * Gets the CPS interface 
+    * Detach the CPS interface 
     *
     * @since S60 5.2